Subject: [PATCH gnome-team 11/12] gnu: mutter: Update to 46.4.

From: Liliana Marie Prikler <[email-masked]>
Date: Sun, 8 Sep 2024 22:21:05 +0200

* gnu/packages/gnome.scm (mutter): Update to 46.4.
[#:configure-flags]: Update accordingly.
[native-inputs]: Replace wayland-protocols with wayland-protocols-next.
Add libei.
[inputs]: Add linux-libre-headers-6.1.
---
 gnu/packages/gnome.scm | 14 ++++++++------
 1 file changed, 8 insertions(+), 6 deletions(-)

diff --git a/gnu/packages/gnome.scm b/gnu/packages/gnome.scm
index 71aeec0905..90669e6703 100644
--- a/gnu/packages/gnome.scm
+++ b/gnu/packages/gnome.scm
@@ -7976,7 +7976,7 @@ (define-public zenity
 (define-public mutter
   (package
     (name "mutter")
-    (version "44.9")
+    (version "46.4")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://gnome/sources/" name "/"
@@ -7984,7 +7984,7 @@ (define-public mutter
                                   name "-" version ".tar.xz"))
               (sha256
                (base32
-                "0b7wzaj67qzrhgclvqk10fwk4524j4qppl88822mxxlqr40frfnk"))))
+                "1r02fp1z5ikm9ml2m4dvnfdn3nig4wj45cz2gicmdnrak37xj6v1"))))
     ;; NOTE: Since version 3.21.x, mutter now bundles and exports forked
     ;; versions of cogl and clutter.  As a result, many of the inputs,
     ;; propagated-inputs, and configure flags used in cogl and clutter are
@@ -8001,7 +8001,7 @@ (define-public mutter
          ;; Otherwise, the RUNPATH will lack the final path component.
          (string-append "-Dc_link_args=-Wl,-rpath="
                         #$output "/lib,-rpath="
-                        #$output "/lib/mutter-12")
+                        #$output "/lib/mutter-14")
          ;; Disable systemd support.
          "-Dsystemd=false"
          ;; Don't install tests.
@@ -8124,19 +8124,20 @@ (define-public mutter
            autoconf
            automake
            libtool
-           wayland-protocols
+           wayland-protocols-next
            ;; For tests.
            ;; Warnings are configured to be fatal during the tests; add an icon
            ;; theme to please libxcursor.
            adwaita-icon-theme
+           libei
            libxcursor                   ;for XCURSOR_PATH
            pipewire
            python
            python-dbus
            python-dbusmock))
     (propagated-inputs
-     (list gsettings-desktop-schemas      ;required by libmutter-12.pc
-           ;; mutter-clutter-12.pc and mutter-cogl-12.pc refer to these:
+     (list gsettings-desktop-schemas      ;required by libmutter-14.pc
+           ;; mutter-clutter-14.pc and mutter-cogl-14.pc refer to these:
            at-spi2-core
            cairo
            eudev
@@ -8171,6 +8172,7 @@ (define-public mutter
            libxkbfile
            libxrandr
            libxtst
+           linux-libre-headers-6.1      ; for dma_buf_export_sync_file
            pipewire
            startup-notification
            sysprof
-- 
2.45.2